==> fiphopha-0.1.8-py3-none-any.whl: fiphopha-0.1.8.dist-info/licenses/LICENSE.md <==
MIT License

Copyright (c) 2025 Vasilios Drakopoulos

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

In addition, any person or entity using, adapting, or modifying this Software
must give appropriate credit by citing the original publication and author (Vasilios Drakopoulos).

This citation must be included in any publication, work, or research that uses this Software.

The citation requirement can be fulfilled by providing a reference to the publication in any reasonable manner, 
but not in any way that suggests the licensor endorses you or your use of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> fiphopha-0.2.1-py3-none-any.whl: fiphopha-0.2.1.dist-info/licenses/LICENSE.md <==
MIT License

Copyright (c) 2025 Vasilios Drakopoulos

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

In addition, any person or entity using, adapting, or modifying this Software
must give appropriate credit by citing the original publication (https://www.biorxiv.org/content/10.1101/2025.06.12.659422v1) and author (Vasilios Drakopoulos).

This citation must be included in any publication, work, or research that uses this Software.

The citation requirement can be fulfilled by providing a reference to the publication in any reasonable manner, 
but not in any way that suggests the licensor endorses you or your use of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
